==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kicker/applets/launcher/quickbutton.h <==
/*****************************************************************

Copyright (c) 2000 Bill Nagel

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __quickbutton_h__
#define __quickbutton_h__

#include <qbutton.h>
#include <qpoint.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qcursor.h>

class QPopupMenu;

class QuickButton : public QButton
{
   Q_OBJECT
public:
   QuickButton(const QString &u, QWidget *parent=0, const char *name=0);
   ~QuickButton();
   QString getURL();
signals:
   void removeIcon(QuickButton *);
protected:
   void drawButton(QPainter *p);
   void drawButtonLabel(QPainter *p);
   void enterEvent(QEvent *e);
   void leaveEvent(QEvent *e);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
protected slots:
   void slotSettingsChanged(int);
   void slotIconChanged(int);
   void slotExec();
   void slotRemove();
private:
   QPoint dragPos;
   QPopupMenu *popup;
   QString url;
   QPixmap icon, iconh;
   QCursor oldCursor;
   bool highlight, local, changeCursorOverItem;
};

#endif

==> kdebase-3.2.3.tar.bz2: kdebase-3.2.3/kicker/applets/launcher/quickbutton.h <==
/*****************************************************************

Copyright (c) 2000 Bill Nagel

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#ifndef __quickbutton_h__
#define __quickbutton_h__

#include <qbutton.h>
#include <qpoint.h>
#include <qstring.h>
#include <qpixmap.h>
#include <qcursor.h>

#include <kurl.h>
#include <kservice.h>

class QPopupMenu;

class QuickButton : public QButton
{
   Q_OBJECT
public:
   QuickButton(const QString &u, QWidget *parent=0, const char *name=0);
   ~QuickButton();
   QString getURL();
   QString getId();
   QPixmap getIcon() { return icon; }

signals:
   void removeIcon(QuickButton *);
protected:
   void paintEvent( QPaintEvent * );
   void drawButton(QPainter *p);
   void drawButtonLabel(QPainter *p);
   void enterEvent(QEvent *e);
   void leaveEvent(QEvent *e);
   void mousePressEvent(QMouseEvent *e);
   void mouseMoveEvent(QMouseEvent *e);
protected slots:
   void slotSettingsChanged(int);
   void slotIconChanged(int);
   void slotExec();
   void slotRemove();
private:
   QPoint dragPos;
   QPopupMenu *popup;
   KService::Ptr service;
   KURL url;
   QString id;
   QPixmap icon, iconh;
   QCursor oldCursor;
   bool highlight, changeCursorOverItem;
};

#endif
